<?php
/**
 * Copyright (C) 2017-2019 Petr Hucik <petr@getdatakick.com>
 *
 * NOTICE OF LICENSE
 *
 * Licensed under the DataKick Regular License version 1.0
 * For more information see LICENSE.txt file
 *
 * @author    Petr Hucik <petr@getdatakick.com>
 * @copyright 2017-2019 Petr Hucik
 * @license   Licensed under the DataKick Regular License version 1.0
 */

namespace Conseqs\Actions;

use Category;
use Conseqs\Parameters\BooleanParameterDefinition;
use Conseqs\Parameters\IntParameterDefinition;
use Conseqs\Action;
use Conseqs\RuntimeModifier;
use Conseqs\ParameterValues;
use Conseqs\ParameterDefinitions;
use PrestaShopException;
use Product;
use Validate;

class AddProductCategory extends Action
{
    /**
     * @return string
     */
    public function getName()
    {
        return $this->l('Associate product with category');
    }

    /**
     * @return ParameterDefinitions
     */
    public function getSettingsParameters()
    {
        return ParameterDefinitions::none();
    }


    /**
     * @return string
     */
    public function getDescription()
    {
        return $this->l('This action will associate product with specific category');
    }

    /**
     * @param ParameterValues $settings
     * @return ParameterDefinitions
     */
    public function getInputParameters(ParameterValues $settings)
    {
        return new ParameterDefinitions([
            'params.product' => new IntParameterDefinition($this->l('Product ID')),
            'params.category' => new IntParameterDefinition($this->l('Category ID')),
            'params.makeDefault' => new BooleanParameterDefinition($this->l('Set as default category')),
        ]);
    }

    /**
     * @param ParameterValues $settings
     * @param ParameterValues $input
     * @param ParameterValues $triggerOutput
     * @param RuntimeModifier $runtimeModifier
     * @return bool
     * @throws PrestaShopException
     */
    public function execute(ParameterValues $settings, ParameterValues $input, ParameterValues $triggerOutput, RuntimeModifier $runtimeModifier)
    {
        $productId = (int)$input->getValue('params.product');
        $categoryId = (int)$input->getValue('params.category');
        $makeDefault = (bool)$input->getValue('params.makeDefault');
        $product = new Product($productId);
        if (! Validate::isLoadedObject($product)) {
            throw new PrestaShopException("Product with id $productId not found");
        }
        $category = new Category($categoryId);
        if (! Validate::isLoadedObject($category)) {
            throw new PrestaShopException("Category with id $categoryId not found");
        }
        $product->addToCategories([ $categoryId ]);
        if ($makeDefault) {
            if ((int)$product->id_category_default !== $categoryId) {
                $product->id_category_default = $categoryId;
                $product->update();
            }
        }
        return true;
    }
}